// zGoBoard.cpp: implementation of the zGoBoard class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "zGoBoard.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

zGoBoard::zGoBoard()
{
	viewSize=400; 
	boardSize=19;
	xMin=0;
	yMin=0;
	reset();
}

void zGoBoard::reset()
{
	stepSize=viewSize/(boardSize+1);
	starDiameter=(int) stepSize/4;
}
zGoBoard::~zGoBoard()
{

}

void zGoBoard::drawBoardbase(CDC *Dc){
	//set parameters
	double penSize=0.01;
	int i;
	int j;

	//paint background
	CBrush *boardBrush = new CBrush(RGB(192,192,192));
	Dc->SelectObject(boardBrush);
	CRect *rect = new CRect(xMin,yMin,viewSize+xMin,viewSize+yMin);
	Dc->FillRect(rect,boardBrush);

	//paint lines
	CPen pen(0, 1, RGB(64,64,64));
	Dc->SelectObject(pen);
	for (i=1;i<=boardSize;i++) {
		int x = xMin + i * stepSize;
		Dc->MoveTo(x,yMin+stepSize);
		Dc->LineTo(x,yMin+boardSize*stepSize);
	}
	for (i=1;i<=boardSize;i++) {
		int y = yMin + i * stepSize;
		Dc->MoveTo(xMin + stepSize,y);
		Dc->LineTo(xMin+boardSize*stepSize,y);
	}

	//paint stars
	CBrush *starBrush = new CBrush(RGB(64,64,64));
	Dc->SelectObject(starBrush);
	if (boardSize == 19 || boardSize == 13) {
		int offset = starDiameter/2;
		for (j=4;j<boardSize;j+=6) {
			int y = yMin + j * stepSize - offset;
			for (i=4;i<boardSize;i+=6) {
				int x = xMin + i * stepSize - offset;
				Dc->Ellipse(x,y,x+starDiameter,y+starDiameter);
			}
		}
	}
	delete rect;
	delete boardBrush;
	delete starBrush;
}

void zGoBoard::drawBoardState()
{

}

void zGoBoard::drawBoard()
{

}

void zGoBoard::drawStone(CDC *dc, int i, int j, int color, int _last)
{
	int m;
	int n;
	CPoint screenCoor;
	CPoint boardCorr;
	if (i<0 || j<0) return;
	boardCorr.x = i;
	boardCorr.y = j;
	boardCoorCoorToScreen(boardCorr,&screenCoor);
	m = screenCoor.x;
	n = screenCoor.y;
	CPen pen;
	CBrush *boardBrush;
	if (color == 1) {
		pen.CreatePen(1,1,RGB(255,255,255));
		boardBrush = new CBrush(RGB(255,255,255));
	}
	else {
		pen.CreatePen(1,0,RGB(0,0,0));
		boardBrush = new CBrush(RGB(0,0,0));
	}
	dc->SelectObject(pen);
	dc->SelectObject(boardBrush);
	dc->Ellipse(m,n,m+20,n+20);
	if (_last) {
		boardBrush = new CBrush(RGB(0,255,0));
		dc->SelectObject(boardBrush);
		dc->Ellipse(m+5,n+5,m+15,n+15);
	}
	delete boardBrush;
}

void zGoBoard::drawDragonStone(CDC *dc, int i, int j, int color, int _id)
{
	int m;
	int n;
	CPoint screenCoor;
	CPoint boardCorr;
	boardCorr.x = i;
	boardCorr.y = j;
	boardCoorCoorToScreen(boardCorr,&screenCoor);
	m = screenCoor.x;
	n = screenCoor.y;
	CPen pen;
	CBrush *boardBrush;
	if (color == 0) {
		pen.CreatePen(1,1,RGB(164,164,164));
		boardBrush = new CBrush(RGB(164,164,121647));
		dc->SetTextColor(RGB(255,255,255));
		dc->SetBkColor(RGB(164,164,164));
	}
	if (color == 1) {
		pen.CreatePen(1,1,RGB(255,255,255));
		boardBrush = new CBrush(RGB(255,255,255));
		dc->SetTextColor(RGB(0,0,0));
		dc->SetBkColor(RGB(255,255,255));
	}
	if (color == 2) {
		pen.CreatePen(1,0,RGB(0,0,0));
		boardBrush = new CBrush(RGB(0,0,0));
		dc->SetTextColor(RGB(255,255,255));
		dc->SetBkColor(RGB(0,0,0));
	}
	dc->SelectObject(pen);
	dc->SelectObject(boardBrush);
	//dc->Arc(m,n,m+20,n+20,m,n,m,n);
	dc->Ellipse(m,n,m+20,n+20);
	CString str;
	str.Format("%02i",_id);
	dc->TextOut(m+2,n+2,str,2);
	delete boardBrush;
}

void zGoBoard::screenCoorToBoardCoor(CPoint _screenCoor, CPoint *_boardCoor)
{
	_boardCoor->x = (_screenCoor.x - xMin + stepSize / 2) / stepSize - 1;
	_boardCoor->y = (_screenCoor.y - yMin + stepSize / 2) / stepSize - 1;
}

void zGoBoard::boardCoorCoorToScreen(CPoint _boardCoor, CPoint *_screenCoor)
{
	_screenCoor->x = xMin+ (_boardCoor.x+1)*stepSize-(int)starDiameter/2 - 7;
	_screenCoor->y = yMin+ (_boardCoor.y+1)*stepSize-(int)starDiameter/2 - 7;
}

